@@ -59,6 +59,7 @@ class TransformerSrlSpan(SrlBert):
         srl_eval_path: str = DEFAULT_SRL_EVAL_PATH,
         restrict_frames: bool = False,
         restrict_roles: bool = False,
+        inventory: str = "verbatlas",
         **kwargs,
     ) -> None:
         # bypass SrlBert constructor
@@ -69,9 +70,10 @@ class TransformerSrlSpan(SrlBert):
         self.restrict_roles = restrict_roles
         self.transformer = AutoModel.from_pretrained(bert_model)
         self.frame_criterion = nn.CrossEntropyLoss()
-        # add missing labels
-        frame_list = load_label_list(FRAME_LIST_PATH)
-        self.vocab.add_tokens_to_namespace(frame_list, "frames_labels")
+        if inventory == "verbatlas":
+            # add missing labels
+            frame_list = load_label_list(FRAME_LIST_PATH)
+            self.vocab.add_tokens_to_namespace(frame_list, "frames_labels")
         self.num_classes = self.vocab.get_vocab_size("labels")
         self.frame_num_classes = self.vocab.get_vocab_size("frames_labels")
         if srl_eval_path is not None:
