@@ -1,10 +1,11 @@
+import enum
 from typing import List, Dict, Type
+from allennlp.data.tokenizers.token import Token
 
 import numpy
 from allennlp.common import plugins
 from allennlp.common.util import JsonDict, sanitize, group_by_count
 from allennlp.data import DatasetReader, Instance
-from allennlp.data.tokenizers.spacy_tokenizer import SpacyTokenizer
 from allennlp.models import Model
 from allennlp.models.archival import Archive, load_archive
 from allennlp.predictors.predictor import Predictor
@@ -26,12 +27,23 @@ class SrlTransformersPredictor(SemanticRoleLabelerPredictor):
         srl_string = srl_string.replace("[V", "[" + frame)
         return srl_string
 
+    @overrides
+    def _sentence_to_srl_instances(self, json_dict: JsonDict) -> List[Instance]:
+        sentence = json_dict["sentence"]
+        if json_dict.get("verbs"):
+            text = sentence.split()
+            pos = ["VERB" if i == json_dict["verbs"] else "NOUN" for i, _ in enumerate(text)]
+            tokens = [Token(t, i, i + len(text), pos_=p) for i, (t, p) in enumerate(zip(text, pos))]
+        else:
+            tokens = self._tokenizer.tokenize(sentence)
+        return self.tokens_to_instances(tokens)
+
     @overrides
     def tokens_to_instances(self, tokens):
         words = [token.text for token in tokens]
         instances: List[Instance] = []
         for i, word in enumerate(tokens):
-            if word.pos_ == "VERB":
+            if word.pos_ in ["AUX", "VERB"]:
                 verb_labels = [0 for _ in words]
                 verb_labels[i] = 1
                 instance = self._dataset_reader.text_to_instance(
@@ -135,7 +147,8 @@ class SrlTransformersPredictor(SemanticRoleLabelerPredictor):
         frozen: bool = True,
         import_plugins: bool = True,
         language: str = "en_core_web_sm",
-        restrict: bool = False,
+        restrict_frames: bool = False,
+        restrict_roles: bool = False,
     ) -> "Predictor":
         if import_plugins:
             plugins.import_plugins()
@@ -145,7 +158,8 @@ class SrlTransformersPredictor(SemanticRoleLabelerPredictor):
             dataset_reader_to_load=dataset_reader_to_load,
             frozen=frozen,
             language=language,
-            restrict=restrict,
+            restrict_frames=restrict_frames,
+            restrict_roles=restrict_roles,
         )
 
     @classmethod
